<template>
  <el-dialog
    width="60%"
    title="员工"
    top="5vh"
    :visible.sync="innerVisible"
    append-to-body
    @close="$emit('update:currshowlist', false)"
    :show="currshowlist"
    class="staff-dialog"
  >
    <ttable
      :table="table"
      @handleSelectionChange="handleSelectionChange"
      @currentChange="handleCurrentChange"
      :uploadInfo="uploadInfo"
      :prelang="prelang"
      :options="options"
      :selColValArr="paramSelArr"
      :selCol="paramSelCol"
      :bottomOffset="350"
      :ajaxFun="ajaxFun"
      ref="commonStaffTable"
    >
      <template #toolbar></template>
    </ttable>

    <div slot="footer" class="dialog-footer">
      <el-button @click="innerVisible = false">取 消</el-button>
      <el-button type="primary" @click="saveSelectRow">确 定</el-button>
    </div>
  </el-dialog>
</template>
<script>
import ttable from '@/views/common/ztt-table'
import { fetchList } from '@/api/basic/staff'

export default {
  props: {
    currshowlist: {
      type: Boolean,
      default: false
    },
    multiSelect: {
      type: Boolean,
      default: false
    },
    // 默认选中字段的值数组
    paramSelArr: {
      type: Array,
      default: () => {
        return []
      }
    },
    // 默认选中字段
    paramSelCol: {
      type: String
    }
  },
  data() {
    return {
      ajaxFun: fetchList,
      innerVisible: false,
      currentRow: null,
      paramName: null,
      multipleSelection: [],
      uploadInfo: {
        // 是否展示上传EXCEL以及对应的url
        isShow: false,
        url: ''
      },
      prelang: 'operation',
      options: {
        height: 300, // 默认高度-为了表头固定
        stripe: true, // 是否为斑马纹 table
        highlightCurrentRow: false, // 是否要高亮当前行
        border: true, // 是否有纵向边框
        lazy: false, // 是否需要懒加载
        fit: true, // 列的宽度是否自撑开
        multiSelect: this.multiSelect, //
        seqNo: true,
        isRefresh: true, // 是否显示刷新按钮
        isShowHide: true, // 是否显示显影按钮
        isSearch: false, // 高级查询按钮
        defaultOrderBy: { column: 'id', direction: 'desc' }
      },
      table: {
        total: 0,
        currentPage: 1,
        pageSize: 20,
        data: [],
        // 标题
        column: [
          {
            minWidth: '100',
            prop: 'staffNo',
            label: '人员编号',
            sort: true,
            isTrue: true,
            isSearch: true,
            searchInfoType: 'text'
          },
          {
            minWidth: '100',
            prop: 'staffName',
            label: '人员名称',
            sort: true,
            isTrue: true,
            isSearch: true,
            searchInfoType: 'text'
          },
          {
            minWidth: '100',
            prop: 'divisionName',
            label: '部门',
            sort: true,
            isTrue: true,
            isSearch: true,
            searchInfoType: 'text'
          },
          {
            minWidth: '100',
            prop: 'phone',
            label: '电话',
            sort: true,
            isTrue: true,
            isSearch: true,
            searchInfoType: 'text'
          },
          {
            minWidth: '100',
            prop: 'email',
            label: '邮箱',
            sort: true,
            isTrue: true,
            isSearch: true,
            searchInfoType: 'text'
          },
          {
            minWidth: '100',
            prop: 'post',
            label: '岗位',
            sort: true,
            isTrue: true,
            isSearch: true,
            searchInfoType: 'text'
          },
          {
            minWidth: '100',
            prop: 'createTime',
            label: '创建时间',
            sort: true,
            isTrue: true,
            isSearch: true,
            searchInfoType: 'datetimerange'
          }
        ]
      },
      addOrUpdateVisible: false
    }
  },
  components: {
    ttable
  },
  methods: {
    init(param) {
      this.paramName = param
    },
    saveSelectRow() {
      if (this.multiSelect) {
        this.$emit(
          'handleSelectionChange',
          this.multipleSelection,
          this.paramName
        )
      } else {
        this.$emit('listenToStaffEvent', this.currentRow)
      }
      this.innerVisible = false
    },
    handleCurrentChange(row) {
      this.currentRow = row
    },
    handleSelectionChange(val) {
      // 多行选中
      this.multipleSelection = val
    },
    getData() {
      if (this.$refs.commonStaffTable !== undefined) {
        this.$refs.commonStaffTable.getDataList()
      }
    }
  },
  watch: {
    currshowlist() {
      this.innerVisible = this.currshowlist
      if (this.currshowlist) {
        this.$nextTick(() => {
          this.getData()
        })
      }
    }
  }
}
</script>
<style>
.staff-dialog .el-dialog__header {
  padding: 10px 20px 10px;
}
.staff-dialog .el-dialog__header .el-dialog__headerbtn {
  top: 10px;
}
.staff-dialog .el-dialog__body {
  padding: 5px 20px;
}

.staff-dialog .el-dialog__footer {
  padding: 5px 20px 10px;
}

.staff-dialog .el-dialog__body .avue-crud__pagination {
  margin-top: 0px;
  margin-bottom: 5px;
}
</style>
